==> ecuacion-splib-web-1.109.0-sources.jar: jp/ecuacion/splib/web/bean/SplibModelAttributes.java <==
package jp.ecuacion.splib.web.bean;

import java.util.HashMap;
import java.util.Map;
import org.springframework.ui.Model;

/** modelAttribute. */
public class SplibModelAttributes extends HashMap<String, Object> {

  private static final long serialVersionUID = 1L;

  // optionalだがlibrary側で対応が入っているものはあらかじめ本classないで管理しておく

  private boolean bsBgGradient = true;

  /**
   * 基本はlight(default) / dark の2種類しか設定しないと思われるが、
   * カラーモードを追加することもbootstrapとしては可能なので、内部的にはカラーモード名を持つ形とする。 通常使うものでもないのでdefaultでlightとしておく。
   */
  private boolean bsDarkMode = false;

  private String navbarBgColor;

  private String navbarBgColorPublic;

  private String navbarBgColorAccount;

  private String navbarBgColorAdmin;

  private boolean showsMessagesLinkedToItemsAtTheTop = true;

  private boolean showsMessagesLinkedToItemsAtEachField = false;

  /**
   * library側で対応は入っていないがapp共通で登録したいmodelAttributeはここに登録。
   * SystemCommonControllerに@ModelAttributeで登録してもいいのだが、library側で対応している項目はここに定義しているので
   * それ以外も併せて本クラスで一限管理することとする。
   */
  private Map<String, Object> appCommonModelAttributeMap;


  public Map<String, Object> getAppCommonModelAttributeMap() {
    return appCommonModelAttributeMap;
  }

  /** 追加は、mapをgetするのではなく、わかりやすくkey, valueを引数に渡す形で登録。 */
  public void addAppCommonModelAttribute(String key, Object value) {
    this.appCommonModelAttributeMap.put(key, value);
  }

  public boolean getBsBgGradient() {
    return bsBgGradient;
  }

  public void setBsBgGradient(boolean bsBgGradient) {
    this.bsBgGradient = bsBgGradient;
  }

  public boolean getBsDarkMode() {
    return bsDarkMode;
  }

  public void setBsDarkMode(boolean bsDarkMode) {
    this.bsDarkMode = bsDarkMode;
  }

  public String getNavbarBgColor() {
    return navbarBgColor;
  }

  public void setNavbarBgColor(String navbarBgColor) {
    this.navbarBgColor = navbarBgColor;
  }

  public String getNavbarBgColorPublic() {
    return navbarBgColorPublic;
  }

  public void setNavbarBgColorPublic(String navbarBgColorPublic) {
    this.navbarBgColorPublic = navbarBgColorPublic;
  }

  public String getNavbarBgColorAccount() {
    return navbarBgColorAccount;
  }

  public void setNavbarBgColorAccount(String navbarBgColorAccount) {
    this.navbarBgColorAccount = navbarBgColorAccount;
  }

  public String getNavbarBgColorAdmin() {
    return navbarBgColorAdmin;
  }

  public void setNavbarBgColorAdmin(String navbarBgColorAdmin) {
    this.navbarBgColorAdmin = navbarBgColorAdmin;
  }

  public boolean isShowsMessagesLinkedToItemsAtTheTop() {
    return showsMessagesLinkedToItemsAtTheTop;
  }

  public void setShowsMessagesLinkedToItemsAtTheTop(boolean showsMessagesLinkedToItemsAtTheTop) {
    this.showsMessagesLinkedToItemsAtTheTop = showsMessagesLinkedToItemsAtTheTop;
  }

  public boolean isShowsMessagesLinkedToItemsAtEachField() {
    return showsMessagesLinkedToItemsAtEachField;
  }

  public void setShowsMessagesLinkedToItemsAtEachField(
      boolean showsMessagesLinkedToItemsAtEachField) {
    this.showsMessagesLinkedToItemsAtEachField = showsMessagesLinkedToItemsAtEachField;
  }

  public void addAllToModel(Model model) {
    model.addAttribute("bsBgGradient", bsBgGradient);
    model.addAttribute("bsDarkMode", bsDarkMode);
    model.addAttribute("navbarBgColor", navbarBgColor);
    model.addAttribute("navbarBgColorPublic", navbarBgColorPublic);
    model.addAttribute("navbarBgColorAccount", navbarBgColorAccount);
    model.addAttribute("navbarBgColorAdmin", navbarBgColorAdmin);
    model.addAttribute("showsMessagesLinkedToItemsAtTheTop", showsMessagesLinkedToItemsAtTheTop);
    model.addAttribute("showsMessagesLinkedToItemsAtEachField",
        showsMessagesLinkedToItemsAtEachField);
  }
}

==> ecuacion-splib-web-2.8.2-sources.jar: jp/ecuacion/splib/web/bean/SplibModelAttributes.java <==
package jp.ecuacion.splib.web.bean;

import java.util.HashMap;
import java.util.Map;
import org.springframework.ui.Model;

/** modelAttribute. */
public class SplibModelAttributes extends HashMap<String, Object> {

  private static final long serialVersionUID = 1L;

  // optionalだがlibrary側で対応が入っているものはあらかじめ本classないで管理しておく

  private boolean bsBgGradient = true;

  /**
   * 基本はlight(default) / dark の2種類しか設定しないと思われるが、
   * カラーモードを追加することもbootstrapとしては可能なので、内部的にはカラーモード名を持つ形とする。 通常使うものでもないのでdefaultでlightとしておく。
   */
  private boolean bsDarkMode = false;

  private String navbarBgColor;

  private String navbarBgColorPublic;

  private String navbarBgColorAccount;

  private String navbarBgColorAdmin;

  private boolean showsMessagesLinkedToItemsAtTheTop = true;

  private boolean showsMessagesLinkedToItemsAtEachField = false;

  /**
   * library側で対応は入っていないがapp共通で登録したいmodelAttributeはここに登録。
   * SystemCommonControllerに@ModelAttributeで登録してもいいのだが、library側で対応している項目はここに定義しているので
   * それ以外も併せて本クラスで一限管理することとする。
   */
  private Map<String, Object> appCommonModelAttributeMap = new HashMap<>();


  public Map<String, Object> getAppCommonModelAttributeMap() {
    return appCommonModelAttributeMap;
  }

  /** 追加は、mapをgetするのではなく、わかりやすくkey, valueを引数に渡す形で登録。 */
  public void addAppCommonModelAttribute(String key, Object value) {
    this.appCommonModelAttributeMap.put(key, value);
  }

  public boolean getBsBgGradient() {
    return bsBgGradient;
  }

  public void setBsBgGradient(boolean bsBgGradient) {
    this.bsBgGradient = bsBgGradient;
  }

  public boolean getBsDarkMode() {
    return bsDarkMode;
  }

  public void setBsDarkMode(boolean bsDarkMode) {
    this.bsDarkMode = bsDarkMode;
  }

  public String getNavbarBgColor() {
    return navbarBgColor;
  }

  public void setNavbarBgColor(String navbarBgColor) {
    this.navbarBgColor = navbarBgColor;
  }

  public String getNavbarBgColorPublic() {
    return navbarBgColorPublic;
  }

  public void setNavbarBgColorPublic(String navbarBgColorPublic) {
    this.navbarBgColorPublic = navbarBgColorPublic;
  }

  public String getNavbarBgColorAccount() {
    return navbarBgColorAccount;
  }

  public void setNavbarBgColorAccount(String navbarBgColorAccount) {
    this.navbarBgColorAccount = navbarBgColorAccount;
  }

  public String getNavbarBgColorAdmin() {
    return navbarBgColorAdmin;
  }

  public void setNavbarBgColorAdmin(String navbarBgColorAdmin) {
    this.navbarBgColorAdmin = navbarBgColorAdmin;
  }

  public boolean isShowsMessagesLinkedToItemsAtTheTop() {
    return showsMessagesLinkedToItemsAtTheTop;
  }

  public void setShowsMessagesLinkedToItemsAtTheTop(boolean showsMessagesLinkedToItemsAtTheTop) {
    this.showsMessagesLinkedToItemsAtTheTop = showsMessagesLinkedToItemsAtTheTop;
  }

  public boolean isShowsMessagesLinkedToItemsAtEachField() {
    return showsMessagesLinkedToItemsAtEachField;
  }

  public void setShowsMessagesLinkedToItemsAtEachField(
      boolean showsMessagesLinkedToItemsAtEachField) {
    this.showsMessagesLinkedToItemsAtEachField = showsMessagesLinkedToItemsAtEachField;
  }

  public void addAllToModel(Model model) {
    model.addAttribute("bsBgGradient", bsBgGradient);
    model.addAttribute("bsDarkMode", bsDarkMode);
    model.addAttribute("navbarBgColor", navbarBgColor);
    model.addAttribute("navbarBgColorPublic", navbarBgColorPublic);
    model.addAttribute("navbarBgColorAccount", navbarBgColorAccount);
    model.addAttribute("navbarBgColorAdmin", navbarBgColorAdmin);
    model.addAttribute("showsMessagesLinkedToItemsAtTheTop", showsMessagesLinkedToItemsAtTheTop);
    model.addAttribute("showsMessagesLinkedToItemsAtEachField",
        showsMessagesLinkedToItemsAtEachField);
  }
}
